( cd usr/bin ; rm -rf vim )
( cd usr/bin ; ln -sf /cdrom/usr/bin/vim vim )
( cd usr/lib ; rm -rf vim.hlp )
( cd usr/lib ; ln -sf /cdrom/usr/lib/vim.hlp vim.hlp )
( cd usr ; rm -rf man )
( cd usr ; ln -sf /cdrom/usr/man man )
( cd usr/doc ; rm -rf vim )
( cd usr/doc ; ln -sf /cdrom/usr/doc/vim vim )
